@@ -4,14 +4,21 @@
 
 #include <fcntl.h>
 #include <termios.h>
-#include <poll.h>
 #include <dirent.h>
 #include <errno.h>
+#ifndef __APPLE__
+#include <poll.h>
+#else
+#include <sys/select.h>
+#endif
 
 #if FF_HAVE_WORDEXP
     #include <wordexp.h>
+#elif FF_HAVE_GLOB
+    #warning "<wordexp.h> is not available, use <glob.h> instead"
+    #include <glob.h>
 #else
-    #warning "<wordexp.h> not available"
+    #warning "Neither <wordexp.h> nor <glob.h> is available"
 #endif
 
 static void createSubfolders(const char* fileName)
@@ -117,7 +124,7 @@ bool ffPathExpandEnv(FF_MAYBE_UNUSED const char* in, FF_MAYBE_UNUSED FFstrbuf* o
     #if FF_HAVE_WORDEXP // https://github.com/termux/termux-packages/pull/7056
 
     wordexp_t exp;
-    if(wordexp(in, &exp, 0) != 0)
+    if (wordexp(in, &exp, 0) != 0)
         return false;
 
     if (exp.we_wordc == 1)
@@ -128,6 +135,20 @@ bool ffPathExpandEnv(FF_MAYBE_UNUSED const char* in, FF_MAYBE_UNUSED FFstrbuf* o
 
     wordfree(&exp);
 
+    #elif FF_HAVE_GLOB
+
+    glob_t gb;
+    if (glob(in, GLOB_NOSORT | GLOB_TILDE, NULL, &gb) != 0)
+        return false;
+
+    if (gb.gl_matchc == 1)
+    {
+        result = true;
+        ffStrbufSetS(out, gb.gl_pathv[0]);
+    }
+
+    globfree(&gb);
+
     #endif
 
     return result;
@@ -140,7 +161,7 @@ void restoreTerm(void)
     tcsetattr(ftty, TCSAFLUSH, &oldTerm);
 }
 
-const char* ffGetTerminalResponse(const char* request, const char* format, ...)
+const char* ffGetTerminalResponse(const char* request, int nParams, const char* format, ...)
 {
     if (ftty < 0)
     {
@@ -161,20 +182,54 @@ const char* ffGetTerminalResponse(const char* request, const char* format, ...)
     ffWriteFDData(ftty, strlen(request), request);
 
     //Give the terminal some time to respond
+    #ifndef __APPLE__
     if(poll(&(struct pollfd) { .fd = ftty, .events = POLLIN }, 1, FF_IO_TERM_RESP_WAIT_MS) <= 0)
-        return "poll() timeout or failed";
+        return "poll(/dev/tty) timeout or failed";
+    #else
+    {
+        // On macOS, poll(/dev/tty) always returns immediately
+        // See also https://nathancraddock.com/blog/macos-dev-tty-polling/
+        fd_set rd;
+        FD_ZERO(&rd);
+        FD_SET(ftty, &rd);
+        if(select(ftty + 1, &rd, NULL, NULL, &(struct timeval) { .tv_sec = FF_IO_TERM_RESP_WAIT_MS / 1000, .tv_usec = (FF_IO_TERM_RESP_WAIT_MS % 1000) * 1000 }) <= 0)
+            return "select(/dev/tty) timeout or failed";
+    }
+    #endif
 
-    char buffer[512];
-    ssize_t bytesRead = read(ftty, buffer, sizeof(buffer) - 1);
-
-    if(bytesRead <= 0)
-        return "read(STDIN_FILENO, buffer, sizeof(buffer) - 1) failed";
-
-    buffer[bytesRead] = '\0';
+    char buffer[1024];
+    size_t bytesRead = 0;
 
     va_list args;
     va_start(args, format);
-    vsscanf(buffer, format, args);
+
+    while (true)
+    {
+        ssize_t nRead = read(ftty, buffer + bytesRead, sizeof(buffer) - bytesRead - 1);
+
+        if (nRead <= 0)
+        {
+            va_end(args);
+            return "read(STDIN_FILENO, buffer, sizeof(buffer) - 1) failed";
+        }
+
+        bytesRead += (size_t) nRead;
+        buffer[bytesRead] = '\0';
+
+        va_list cargs;
+        va_copy(cargs, args);
+        int ret = vsscanf(buffer, format, cargs);
+        va_end(cargs);
+
+        if (ret <= 0)
+        {
+            va_end(args);
+            return "vsscanf(buffer, format, args) failed";
+        }
+        if (ret >= nParams)
+            break;
+    }
+
     va_end(args);
 
     return NULL;
@@ -232,12 +287,15 @@ void listFilesRecursively(uint32_t baseLength, FFstrbuf* folder, uint8_t indenta
 
     while((entry = readdir(dir)) != NULL)
     {
+        if(entry->d_name[0] == '.') // skip hidden files
+            continue;
+
         bool isDir = false;
-#ifdef _DIRENT_HAVE_D_TYPE
+#ifndef __sun
         if(entry->d_type != DT_UNKNOWN && entry->d_type != DT_LNK)
             isDir = entry->d_type == DT_DIR;
         else
-#else
+#endif
         {
             struct stat stbuf;
             if (fstatat(dfd, entry->d_name, &stbuf, 0) < 0)
@@ -245,12 +303,8 @@ void listFilesRecursively(uint32_t baseLength, FFstrbuf* folder, uint8_t indenta
             else
                 isDir = S_ISDIR(stbuf.st_mode);
         }
-#endif
         if (isDir)
         {
-            if(ffStrEquals(entry->d_name, ".") || ffStrEquals(entry->d_name, ".."))
-                continue;
-
             ffStrbufAppendS(folder, entry->d_name);
             ffStrbufAppendC(folder, '/');
             listFilesRecursively(baseLength, folder, (uint8_t) (indentation + 1), entry->d_name, pretty);
