@@ -29,7 +29,7 @@ static const char* detectWithBacklight(FFlist* result)
             continue;
 
         ffStrbufAppendS(&backlightDir, entry->d_name);
-        ffStrbufAppendS(&backlightDir, "/actual_brightness");
+        ffStrbufAppendS(&backlightDir, "/brightness");
         if(ffReadFileBuffer(backlightDir.chars, &buffer))
         {
             double actualBrightness = ffStrbufToDouble(&buffer);
@@ -101,7 +101,7 @@ DDCA_Status ddca_init(const char *libopts, int syslog_level, int opts);
 
 static const char* detectWithDdcci(FFBrightnessOptions* options, FFlist* result)
 {
-    FF_LIBRARY_LOAD(libddcutil, &instance.config.library.libDdcutil, "dlopen ddcutil failed", "libddcutil" FF_LIBRARY_EXTENSION, 5);
+    FF_LIBRARY_LOAD(libddcutil, "dlopen ddcutil failed", "libddcutil" FF_LIBRARY_EXTENSION, 5);
     FF_LIBRARY_LOAD_SYMBOL_MESSAGE(libddcutil, ddca_get_display_info_list2)
     FF_LIBRARY_LOAD_SYMBOL_MESSAGE(libddcutil, ddca_open_display2)
     FF_LIBRARY_LOAD_SYMBOL_MESSAGE(libddcutil, ddca_get_any_vcp_value_using_explicit_type)
