@@ -122,7 +122,7 @@ static void waylandHandleZwlrHead(void *data, FF_MAYBE_UNUSED struct zwlr_output
 
     uint32_t rotation = ffWaylandHandleRotation(&display);
 
-    ffdsAppendDisplay(wldata->result,
+    FFDisplayResult* item = ffdsAppendDisplay(wldata->result,
         (uint32_t) display.width,
         (uint32_t) display.height,
         display.refreshRate / 1000.0,
@@ -131,7 +131,7 @@ static void waylandHandleZwlrHead(void *data, FF_MAYBE_UNUSED struct zwlr_output
         rotation,
         display.edidName.length
             ? &display.edidName
-            : display.description.length
+            : display.description.length && !ffStrbufContain(&display.description, &display.name)
                 ? &display.description
                 : &display.name,
         display.type,
@@ -140,6 +140,19 @@ static void waylandHandleZwlrHead(void *data, FF_MAYBE_UNUSED struct zwlr_output
         (uint32_t) display.physicalWidth,
         (uint32_t) display.physicalHeight
     );
+    if (item)
+    {
+        if (display.hdrSupported)
+            item->hdrStatus = FF_DISPLAY_HDR_STATUS_SUPPORTED;
+        else if (display.hdrInfoAvailable)
+            item->hdrStatus = FF_DISPLAY_HDR_STATUS_UNSUPPORTED;
+        else
+            item->hdrStatus = FF_DISPLAY_HDR_STATUS_UNKNOWN;
+
+        item->manufactureYear = display.myear;
+        item->manufactureWeek = display.mweek;
+        item->serial = display.serial;
+    }
 
     ffStrbufDestroy(&display.description);
     ffStrbufDestroy(&display.name);
