@@ -3,24 +3,11 @@
 #include "common/io/io.h"
 #include "common/properties.h"
 #include "util/mallocHelper.h"
+#include "util/stringUtils.h"
 
 #include <dev/pci/pcireg.h>
 #include <sys/pciio.h>
 #include <fcntl.h>
-#include <paths.h>
-
-static bool loadPciIds(FFstrbuf* pciids)
-{
-    // https://github.com/freebsd/freebsd-src/blob/main/usr.sbin/pciconf/pathnames.h
-
-    ffReadFileBuffer(_PATH_LOCALBASE "/share/pciids/pci.ids", pciids);
-    if (pciids->length > 0) return true;
-
-    ffReadFileBuffer(FASTFETCH_TARGET_DIR_USR "/share/pciids/pci.ids", pciids);
-    if (pciids->length > 0) return true;
-
-    return false;
-}
 
 const char* ffDetectGPUImpl(const FFGPUOptions* options, FFlist* gpus)
 {
@@ -44,8 +31,6 @@ const char* ffDetectGPUImpl(const FFGPUOptions* options, FFlist* gpus)
     if (pcio.status == PCI_GETCONF_ERROR)
         return "ioctl(fd, PCIOCGETCONF, &pc) returned error";
 
-    FF_STRBUF_AUTO_DESTROY pciids = ffStrbufCreate();
-
     for (uint32_t i = 0; i < pcio.num_matches; ++i)
     {
         struct pci_conf* pc = &confs[i];
@@ -55,27 +40,15 @@ const char* ffDetectGPUImpl(const FFGPUOptions* options, FFlist* gpus)
         ffStrbufInit(&gpu->name);
         ffStrbufInitS(&gpu->driver, pc->pd_name);
         ffStrbufInit(&gpu->platformApi);
+        gpu->index = FF_GPU_INDEX_UNSET;
         gpu->temperature = FF_GPU_TEMP_UNSET;
         gpu->coreCount = FF_GPU_CORE_COUNT_UNSET;
+        gpu->coreUsage = FF_GPU_CORE_USAGE_UNSET;
         gpu->type = FF_GPU_TYPE_UNKNOWN;
         gpu->dedicated.total = gpu->dedicated.used = gpu->shared.total = gpu->shared.used = FF_GPU_VMEM_SIZE_UNSET;
-        gpu->deviceId = ((uint64_t) pc->pc_sel.pc_domain << 6) | ((uint64_t) pc->pc_sel.pc_bus << 4) | ((uint64_t) pc->pc_sel.pc_dev << 2) | pc->pc_sel.pc_func;
+        gpu->deviceId = (pc->pc_sel.pc_domain * 100000ull) + (pc->pc_sel.pc_bus * 1000ull) + (pc->pc_sel.pc_dev * 10ull) + pc->pc_sel.pc_func;
         gpu->frequency = FF_GPU_FREQUENCY_UNSET;
 
-        if (gpu->vendor.chars == FF_GPU_VENDOR_NAME_AMD)
-        {
-            char query[32];
-            snprintf(query, sizeof(query), "%X,\t%X,", (unsigned) pc->pc_device, (unsigned) pc->pc_revid);
-            ffParsePropFileData("libdrm/amdgpu.ids", query, &gpu->name);
-        }
-
-        if (gpu->name.length == 0)
-        {
-            if (pciids.length == 0)
-                loadPciIds(&pciids);
-            ffGPUParsePciIds(&pciids, pc->pc_subclass, pc->pc_vendor, pc->pc_device, gpu);
-        }
-
         if (gpu->vendor.chars == FF_GPU_VENDOR_NAME_NVIDIA && (options->temp || options->driverSpecific))
         {
             ffDetectNvidiaGpuInfo(&(FFGpuDriverCondition) {
@@ -87,15 +60,48 @@ const char* ffDetectGPUImpl(const FFGPUOptions* options, FFlist* gpus)
                     .func = pc->pc_sel.pc_func,
                 },
             }, (FFGpuDriverResult) {
+                .index = &gpu->index,
                 .temp = options->temp ? &gpu->temperature : NULL,
                 .memory = options->driverSpecific ? &gpu->dedicated : NULL,
                 .coreCount = options->driverSpecific ? (uint32_t*) &gpu->coreCount : NULL,
                 .type = &gpu->type,
                 .frequency = &gpu->frequency,
+                .coreUsage = &gpu->coreUsage,
+                .name = &gpu->name,
             }, "libnvidia-ml.so");
+        }
 
-            if (gpu->dedicated.total != FF_GPU_VMEM_SIZE_UNSET)
-                gpu->type = gpu->dedicated.total > (uint64_t)1024 * 1024 * 1024 ? FF_GPU_TYPE_DISCRETE : FF_GPU_TYPE_INTEGRATED;
+        if (gpu->name.length == 0)
+        {
+            if (gpu->vendor.chars == FF_GPU_VENDOR_NAME_AMD)
+            {
+                char query[32];
+                snprintf(query, sizeof(query), "%X,\t%X,", (unsigned) pc->pc_device, (unsigned) pc->pc_revid);
+                ffParsePropFileData("libdrm/amdgpu.ids", query, &gpu->name);
+            }
+            if (gpu->name.length == 0)
+            ffGPUFillVendorAndName(pc->pc_subclass, pc->pc_vendor, pc->pc_device, gpu);
+        }
+
+        if (gpu->type == FF_GPU_TYPE_UNKNOWN)
+        {
+            if (gpu->vendor.chars == FF_GPU_VENDOR_NAME_NVIDIA)
+            {
+                if (ffStrbufStartsWithIgnCaseS(&gpu->name, "GeForce") ||
+                    ffStrbufStartsWithIgnCaseS(&gpu->name, "Quadro") ||
+                    ffStrbufStartsWithIgnCaseS(&gpu->name, "Tesla"))
+                    gpu->type = FF_GPU_TYPE_DISCRETE;
+            }
+            else if (gpu->vendor.chars == FF_GPU_VENDOR_NAME_MTHREADS)
+            {
+                if (ffStrbufStartsWithIgnCaseS(&gpu->name, "MTT "))
+                    gpu->type = FF_GPU_TYPE_DISCRETE;
+            }
+            else if (gpu->vendor.chars == FF_GPU_VENDOR_NAME_INTEL)
+            {
+                // 0000:00:02.0 is reserved for Intel integrated graphics
+                gpu->type = gpu->deviceId == 20 ? FF_GPU_TYPE_INTEGRATED : FF_GPU_TYPE_DISCRETE;
+            }
         }
     }
 
