@@ -83,6 +83,8 @@ static pid_t getTerminalInfo(FFTerminalResult* result, pid_t pid)
     {
         //Known shells
         if (
+            ffStrbufEqualS(&result->processName, "sudo")       ||
+            ffStrbufEqualS(&result->processName, "su")         ||
             ffStrbufEqualS(&result->processName, "sh")         ||
             ffStrbufEqualS(&result->processName, "ash")        ||
             ffStrbufEqualS(&result->processName, "bash")       ||
@@ -159,23 +161,30 @@ static bool getTerminalInfoByPidEnv(FFTerminalResult* result, const char* pidEnv
 
 static void getTerminalFromEnv(FFTerminalResult* result)
 {
-    if(
-        result->processName.length > 0 &&
-        !ffStrbufStartsWithS(&result->processName, "login") &&
-        !ffStrbufEqualS(&result->processName, "(login)") &&
+    if (result->processName.length > 0)
+    {
+        if (!ffStrbufStartsWithS(&result->processName, "login") &&
+            !ffStrbufEqualS(&result->processName, "(login)") &&
 
-        #ifdef __APPLE__
-        !ffStrbufEqualS(&result->processName, "launchd") &&
-        !ffStrbufEqualS(&result->processName, "stable") && //for WarpTerminal
-        #else
-        !ffStrbufEqualS(&result->processName, "systemd") &&
-        !ffStrbufEqualS(&result->processName, "init") &&
-        !ffStrbufEqualS(&result->processName, "(init)") &&
-        !ffStrbufEqualS(&result->processName, "SessionLeader") && // #750
-        #endif
+            #ifdef __APPLE__
+            !ffStrbufEqualS(&result->processName, "launchd") &&
+            !ffStrbufEqualS(&result->processName, "stable") && //for WarpTerminal
+            #else
+            !ffStrbufEqualS(&result->processName, "systemd") &&
+            !ffStrbufEqualS(&result->processName, "init") &&
+            !ffStrbufEqualS(&result->processName, "(init)") &&
+            !ffStrbufEqualS(&result->processName, "SessionLeader") && // #750
+            #endif
 
-        !ffStrbufEqualS(&result->processName, "0")
-    ) return;
+            !ffStrbufEqualS(&result->processName, "0")
+        ) return;
+
+        ffStrbufClear(&result->processName);
+        ffStrbufClear(&result->exe);
+        result->exeName = result->exe.chars;
+        ffStrbufClear(&result->exePath);
+        result->pid = result->ppid = 0;
+    }
 
     const char* term = NULL;
 
@@ -274,14 +283,14 @@ static void getUserShellFromEnv(FFShellResult* result)
     }
 }
 
-bool fftsGetShellVersion(FFstrbuf* exe, const char* exeName, FFstrbuf* version);
+bool fftsGetShellVersion(FFstrbuf* exe, const char* exeName, FFstrbuf* exePath, FFstrbuf* version);
 
 bool fftsGetTerminalVersion(FFstrbuf* processName, FFstrbuf* exe, FFstrbuf* version);
 
 static void setShellInfoDetails(FFShellResult* result)
 {
     ffStrbufClear(&result->version);
-    fftsGetShellVersion(&result->exe, result->exeName, &result->version);
+    fftsGetShellVersion(&result->exe, result->exeName, &result->exePath, &result->version);
 
     if(ffStrbufEqualS(&result->processName, "pwsh"))
         ffStrbufInitStatic(&result->prettyName, "PowerShell");
